@@ -10,6 +10,7 @@ import logging
 import os
 import re
 import sys
+from locale import LC_NUMERIC, atof, setlocale
 
 from openpyxl import load_workbook
 
@@ -77,6 +78,8 @@ def convert_date(value, output_format, idx_col, idx_row):
 
 def convert_cell(value, output_format, idx_col, idx_row):
     converted_value = ""
+    if output_format in ("Integer", "Decimal") and str(value).strip() == "":
+        value = "0"
     if "Time" == output_format:
         m = re.match(r"(\d{2})(:)?(\d{2})", value)
         if m:
@@ -93,10 +96,13 @@ def convert_cell(value, output_format, idx_col, idx_row):
         # Decimal numbers must be sent with 2 decimal places and
         # *without* the decimal separator
         try:
-            # Convert to float, multiply by 100, round without decimals,
+            # Convert to string, then float respecting the user's Locale,
+            # multiply by 100, round without decimals,
             # convert to integer (to drop the extra decimal values) then
             # finally back to string...
-            converted_value = float(value)
+            converted_value = str(value)
+            converted_value = atof(converted_value)
+            converted_value = float(converted_value)
             converted_value = converted_value * 100
             converted_value = round(converted_value, 0)
             converted_value = int(converted_value)
@@ -112,7 +118,7 @@ def convert_cell(value, output_format, idx_col, idx_row):
     return converted_value
 
 
-def convert_content(input_content, config, date_field_to_report_on=None):
+def convert_content(input_content, config, date_field_to_report_on=None, truncate=None):
     output_content = []
     if date_field_to_report_on:
         # Argument is 1-based
@@ -143,12 +149,31 @@ def convert_content(input_content, config, date_field_to_report_on=None):
             # Confirm that the length of the field (before padding) is less
             # than the maximum allowed length
             if len(cell) > config[idx_col]["length"]:
-                logging.critical(
-                    "Field %d on row %d (ignoring the header) is too long! Length: %d, "
-                    "max length %d. Exiting..."
-                    % (idx_col + 1, idx_row + 1, len(cell), config[idx_col]["length"])
-                )
-                sys.exit(20)
+                if not truncate or idx_col + 1 not in truncate:
+                    logging.critical(
+                        "Field %d on row %d (ignoring the header) is too long! Length: "
+                        "%d, max length %d. Exiting..."
+                        % (
+                            idx_col + 1,
+                            idx_row + 1,
+                            len(cell),
+                            config[idx_col]["length"],
+                        )
+                    )
+                    sys.exit(20)
+                else:
+                    # Truncate to the defined maximum field length
+                    logging.info(
+                        "Field %d on row %d (ignoring the header) is too long! Length: "
+                        "%d, max length %d. Truncating field to its max length."
+                        % (
+                            idx_col + 1,
+                            idx_row + 1,
+                            len(cell),
+                            config[idx_col]["length"],
+                        )
+                    )
+                    cell = cell[: config[idx_col]["length"]]
 
             padded_output_value = pad_output_value(cell, output_format, length)
             converted_row_content.append(padded_output_value)
@@ -308,6 +333,18 @@ def validate_shared_args(args):
         except ValueError:
             logging.critical("The `--skip-footer` argument must be numeric. Exiting...")
             sys.exit(22)
+    if args.truncate:
+        truncate = []
+        for t in args.truncate.split(","):
+            try:
+                truncate.append(int(t))
+            except ValueError:
+                logging.critical(
+                    "The `--truncate` argument must be a comma-delimited list of "
+                    "numbers. Exiting..."
+                )
+                sys.exit(25)
+        args.truncate = truncate
 
 
 def add_shared_args(parser):
@@ -353,6 +390,25 @@ def add_shared_args(parser):
         required=False,
         default=0,
     )
+    parser.add_argument(
+        "-l",
+        "--locale",
+        help="Change the locale, useful to handle decimal separators",
+        action="store",
+        required=False,
+        default="",
+    )
+    parser.add_argument(
+        "-t",
+        "--truncate",
+        help="Comma-delimited list of field numbers for which the output will be "
+        "truncated at the maximum line length, should the input value be longer than "
+        "the maximum defined field length. If not set, a field that is too long will "
+        "cause the script to stop with an error.",
+        action="store",
+        required=False,
+        default=[],
+    )
 
 
 def parse_args(arguments):
@@ -424,15 +480,31 @@ def process(
     skip_header,
     skip_footer,
     date_field_to_report_on=None,
+    locale="",
+    truncate=None,
 ):
+    # By default, set to the user's default locale, used to appropriately handle
+    # Decimal separators
+    setlocale(LC_NUMERIC, locale)
+
     config = load_config(config)
 
+    if truncate:
+        for t in truncate:
+            if t > len(config):
+                logging.critical(
+                    "The value %d passed in the `--truncate` argument is invalid, it "
+                    "is higher than the %d fields defined in the configuration file. "
+                    "Exiting..." % (t, len(config))
+                )
+                sys.exit(26)
+
     input_content = read_input_file(
         input, delimiter, quotechar, skip_header, skip_footer
     )
 
     (output_content, oldest_date, most_recent_date) = convert_content(
-        input_content, config, date_field_to_report_on
+        input_content, config, date_field_to_report_on, truncate
     )
 
     write_output_file(output_content, output)
@@ -453,6 +525,9 @@ def init():
             args.quotechar,
             args.skip_header,
             args.skip_footer,
+            None,
+            args.locale,
+            args.truncate,
         )
 
 
